#!/bin/sh

# Part of h-e-n, this is not The Right Way(TM) to handle file system mounting.
# ke-recv always runs on Maemo 5 as a daemon, yet it does not properly handle
# mounting.
# Help would be appreciated with ke-recv.

# Thanks to debernardis for help with the script.

prefix=run-standalone.sh

isntfs()
{
	ntfsString=$(parted $partitionName print | grep ntfs)

	if [ "$ntfsString" != "" ]; then
		isNtfsRet=true
	else
		isNtfsRet=false
	fi
	echo "** $partitionName isNTFS=$isNtfsRet **"
}

loadmodules() {
	if [ -f /lib/modules/"`uname -r`"/ntfs.ko ]
		then modprobe ntfs
	fi

	if [ -f /lib/modules/"`uname -r`"/isofs.ko ]
		then modprobe isofs
	fi
} 

mountpartitions() {
	# get list of external partitions
	list=`awk '$4~"[0-9]$"{print $4}' /proc/partitions | grep -v "mmcblk*" | grep -v "loop*" | grep -v "dm-*"`

	if [ "$list" = "" ]; then
		run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"No Device Found"
	fi

	for partitions in $list
	do
		loadmodules
		partitionName=/dev/$partitions
		# check if partitionName is an NTFS partition
		isntfs
		if [ "$isNtfsRet" = "true" ]; then
			#remove old mount from maemo if exists
			umount -f -l /media/usb/$partitions
			rmdir /media/usb/$partitions

			# create in debian with debian driver - allows both R/W operations
			$prefix debian mkdir -p /media/usb/$partitions
			$prefix debian ntfs-3g /dev/$partitions /media/usb/$partitions
			mountedPath=/.debian/media/usb
		else
			#remove old mount from debian if exists
			$prefix debian umount -f -l /media/usb/$partitions
			$prefix debian rmdir /media/usb/$partitions

			# create in maemo
			mkdir -p /media/usb/$partitions
			mount -o uid=29999,gid=29999,utf8,dmask=027,fmask=137 /dev/$partitions /media/usb/$partitions
			mountedPath=/media/usb
		fi
		# "$?" is the return value of a program, 0 means success
		if [ "$?" = "0" ]
			then 
				# LSX edited: org was: without the next line:
				# mount -o remount,rw /media/$partitions

				$prefix dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Successfully mounted /dev/$partitions!"
				# Set a return code here to be read later, useful for opening file manager,
				# otherwise file manager will be called multiple times!
				mounted=yes
		fi
	done
}

unmount() {
	list=`awk '$4~"[0-9]$"{print $4}' /proc/partitions | grep -v "mmcblk*" | grep -v "loop*" | grep -v "dm-*"`

	for partitions in $list
	do
		partitionName=/dev/$partitions
		isntfs

		if [ "$isNtfsRet" = "true" ]; then
			$prefix debian umount -f -l /media/usb/$partitions
			$prefix debian rmdir /media/usb/$partitions
		else
			umount -f -l /media/usb/$partitions
			rmdir /media/usb/$partitions
		fi
	done
	$prefix dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Successfully Unmounted Volumes!"
}   

# lsx - this line added to print on screen the command line - it seems that "--mount" was not sent when "open file manager" preference is on
#$prefix dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"$1"

if [ "$1" = "--mount" ]
	then
		mountpartitions
fi

if [ "$1" = "--unmount" ]
	then
		unmount
fi

#if [ "$2" = "--openfilemanager" ]
#	then
		if [ "$mounted" = "yes" ]
			then
				run-standalone.sh /opt/hamsterfiler/hamsterfiler $mountedPath&
<<COMMENT
				if [ "$3" = "--filebox" ]
					then
						if [ "$isNtfsRet" = "true" ]; then
							filebox /.debian/media/usb
						else
							filebox /media/usb
						fi
						#$prefix dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:"filebox"
				fi
				if [ "$3" = "--osso-filemanager" ]
					then
						$prefix dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:"filemanager"
				fi
COMMENT
		fi
#fi
